herosdevices.hardware.santec.template - Heros Devices 0.5.5 documentation

Skip to content
Back to top
View this page

# herosdevices.hardware.santec.template

Template for Santec SLMs.

## Module Contents

class herosdevices.hardware.santec.template.SantecSLMTemplate

  Template for Santec SLMs.

  Has no functionality, use the derived classes instead.

  abstractmethod firmware_serialnumber() → str

    Get the serial number of the santec firmware running on the SLM.

    This not the same as the serial number used to identify the FTDI chip.

    Returns:

      Serial number.

  abstractmethod video_mode(mode: int = 0) → str

    Query or set the video source the SLM draws the images from.

    Parameters:

      mode – Video source. Consult the manual for for possible sources.

  abstractmethod push_image(slot: int, image: numpy.typing.NDArray[numpy.uint16]) → str

    Upload an image into a specified memory slot.

    Parameters:

      - slot – Slot number. Slot numbers range from 1 to 128.

      - image – The image.

  abstractmethod contrast_level(value: int) → str

    Set the contrast/gamma level of the LCOS.

  abstractmethod display_slot(slot: int = 1) → str

    Set the memory slot to display on the SLM.

    Parameters:

      slot – Slot number. The lowest slot number is 1.